@@ -21,6 +21,7 @@ import warnings
 from functools import partial
 
 from billiard import cpu_count, current_process
+from kombu.utils.encoding import safe_str
 
 from celery import VERSION_BANNER, platforms, signals
 from celery.app import app_or_default
@@ -187,7 +188,7 @@ class Worker(configurated):
 
     def on_consumer_ready(self, consumer):
         signals.worker_ready.send(sender=consumer)
-        print('celery@%s ready.' % self.hostname)
+        print('celery@%s ready.' % safe_str(self.hostname))
 
     def init_queues(self):
         try:
@@ -335,7 +336,8 @@ if not is_jython:
         _shutdown_handler, sig='SIGQUIT', how='Cold', exc=SystemTerminate,
     )
 else:
-    install_worker_term_handler = lambda *a, **kw: None
+    install_worker_term_handler = \
+        install_worker_term_hard_handler = lambda *a, **kw: None
 
 
 def on_SIGINT(worker):
