@@ -37,8 +37,8 @@ class SendmailWarning(UserWarning):
 
 class Message(object):
 
-    def __init__(self, to=None, sender=None, subject=None, body=None,
-            charset='us-ascii'):
+    def __init__(self, to=None, sender=None, subject=None,
+                 body=None, charset='us-ascii'):
         self.to = maybe_list(to)
         self.sender = sender
         self.subject = subject
@@ -60,7 +60,7 @@ class Mailer(object):
     supports_timeout = supports_timeout
 
     def __init__(self, host='localhost', port=0, user=None, password=None,
-            timeout=2, use_ssl=False, use_tls=False):
+                 timeout=2, use_ssl=False, use_tls=False):
         self.host = host
         self.port = port
         self.user = user
@@ -184,7 +184,7 @@ py-celery at %%(hostname)s.
     def should_send(self, context, exc):
         """Returns true or false depending on if a task error mail
         should be sent for this type of error."""
-        allow_classes = tuple(map(symbol_by_name,  self.error_whitelist))
+        allow_classes = tuple(map(symbol_by_name, self.error_whitelist))
         return not self.error_whitelist or isinstance(exc, allow_classes)
 
     def format_subject(self, context):
