@@ -55,7 +55,7 @@ class Entry(object):
 
     def __repr__(self):
         return '<TimerEntry: %s(*%r, **%r)' % (
-                self.fun.__name__, self.args, self.kwargs)
+            self.fun.__name__, self.args, self.kwargs)
 
     if sys.version_info[0] == 3:  # pragma: no cover
 
@@ -73,10 +73,10 @@ class Entry(object):
             return hash(self) == hash(other)
 
 
-def to_timestamp(d):
+def to_timestamp(d, default_timezone=timezone.utc):
     if isinstance(d, datetime):
         if d.tzinfo is None:
-            d = d.replace(tzinfo=timezone.utc)
+            d = d.replace(tzinfo=default_timezone)
         return timedelta_seconds(d - EPOCH)
     return d
 
@@ -203,7 +203,7 @@ class Schedule(object):
 
     def info(self):
         return ({'eta': eta, 'priority': priority, 'item': item}
-                    for eta, priority, item in self.queue)
+                for eta, priority, item in self.queue)
 
     def cancel(self, tref):
         tref.cancel()
@@ -230,7 +230,7 @@ class Timer(threading.Thread):
             super(Timer, self).start(*args, **kwargs)
 
     def __init__(self, schedule=None, on_error=None, on_tick=None,
-            max_interval=None, **kwargs):
+                 max_interval=None, **kwargs):
         self.schedule = schedule or self.Schedule(on_error=on_error,
                                                   max_interval=max_interval)
         self.on_tick = on_tick or self.on_tick
