@@ -81,7 +81,7 @@ from time import sleep
 from Queue import Empty
 
 from kombu.syn import _detect_environment
-from kombu.utils.encoding import safe_repr
+from kombu.utils.encoding import safe_repr, safe_str
 from kombu.utils.eventio import READ, WRITE, ERR
 
 from celery.app import app_or_default
@@ -162,7 +162,7 @@ Will retry using next failover.\
 task_reserved = state.task_reserved
 
 logger = get_logger(__name__)
-info, warn, error, crit = (logger.info, logger.warn,
+info, warn, error, crit = (logger.info, logger.warning,
                            logger.error, logger.critical)
 
 
@@ -340,9 +340,9 @@ class Consumer(object):
                                      hostname=self.hostname,
                                      listener=self,     # pre 2.2
                                      consumer=self)
-        self.pidbox_node = self.app.control.mailbox.Node(self.hostname,
-                                                         state=pidbox_state,
-                                                         handlers=Panel.data)
+        self.pidbox_node = self.app.control.mailbox.Node(
+            safe_str(self.hostname), state=pidbox_state, handlers=Panel.data,
+        )
         conninfo = self.app.connection()
         self.connection_errors = conninfo.connection_errors
         self.channel_errors = conninfo.channel_errors
@@ -419,6 +419,7 @@ class Consumer(object):
             drain_nowait = connection.drain_nowait
             on_task_callbacks = hub.on_task
             keep_draining = connection.transport.nb_keep_draining
+            errors = connection.connection_errors
 
             if hb and connection.supports_heartbeats:
                 hub.timer.apply_interval(
@@ -437,7 +438,6 @@ class Consumer(object):
                     self.handle_unknown_task(body, message, exc)
                 except InvalidTaskError, exc:
                     self.handle_invalid_task(body, message, exc)
-                #fire_timers()
 
             self.task_consumer.callbacks = [on_task_received]
             self.task_consumer.consume()
@@ -453,7 +453,8 @@ class Consumer(object):
 
                 # fire any ready timers, this also returns
                 # the number of seconds until we need to fire timers again.
-                poll_timeout = fire_timers() if scheduled else 1
+                poll_timeout = (fire_timers(propagate=errors) if scheduled
+                                else 1)
 
                 # We only update QoS when there is no more messages to read.
                 # This groups together qos calls, and makes sure that remote
